@@ -13,9 +13,11 @@
 const char *argp_program_bug_address = "chris.wright@nanoporetech.com";
 static char doc[] = 
  "modbam2bed -- summarise one or more BAM with modified base tags to bedMethyl.\
- \vPositions absent from the methylation tags are assumed to be canonical. \
- Positions with modified probability between upper and lower thresholds\
- are removed from the counting process. Column 5 (\"score\") of the output\
+ \vModification information store in the BAM files is examine to derive\
+ an identity of a possibly modified base. Calls are filtered by the\
+ user-provided threshold probability. By default a single-modified base\
+ is reported in the output, though the `--combine` option can fuse\
+ calls for all modification in a family. Column 5 (\"score\") of the output\
  is calculated as the proportion of bases called as the canonical or modified\
  reference base with respect to the number of spanning reads, scaled to a\
  maximum of 1000. Column 10 is the total read coverage including reads with:\
@@ -24,7 +26,9 @@ static char doc[] =
  and deletions. Column 11 is the percentage of reference-base calls identified\
  as being modified (as a proportion of those confidently determined as\
  canonical or modified). Extended output (-e option) can give raw counts\
- of canonical, modified, and undetermined bases for completeness.\
+ of canonical, modified, alternatively modified, and undetermined bases\
+ for completeness. See https://github.com/epi2me-labs/modbam2bed for a\
+ overly precise explanation of the output.\
  \n\nOutput is to standard output unless multiple motif filters are specified.\
  In such cases the --prefix option controls the output file name.";
 static char args_doc[] = "<reference.fasta> <reads.bam> [<reads.bam> ...]";
@@ -37,6 +41,10 @@ static struct argp_option options[] = {
         "Output extended bedMethyl including counts of canonical, modified, and filtered bases (in that order)."},
     {"mod_base", 'm', "BASE", 0,
         "Modified base of interest, one of: 5mC, 5hmC, 5fC, 5caC, 5hmU, 5fU, 5caU, 6mA, 5oxoG, Xao. (Or modA, modC, modG, modT, modU, modN for generic modified base)."},
+    {"combine", 0x800, 0, 0,
+        "Create output with combined modified counts: i.e. alternative modified bases within the same family (same canonical base) are included."},
+    {"aggregate", 0x600, 0, 0,
+        "Output additional aggregated (across strand) counts, requires --cpg or --chg."},
     {"threads", 't', "THREADS", 0,
         "Number of threads for BAM processing."},
     {"prefix", 'p', "PREFIX", 0,
@@ -46,17 +54,17 @@ static struct argp_option options[] = {
     {0, 0, 0, 0,
         "Base filtering options:"},
     {"canon_threshold", 'a', "THRESHOLD", 0,
-        "Bases with mod. probability < THRESHOLD are counted as canonical (default 0.33).", 2},
+        "Deprecated. The option will be removed in a future version. Please use --threshold.", 2},
     {"mod_threshold", 'b', "THRESHOLD", 0,
-        "Bases with mod. probability > THRESHOLD are counted as modified (default 0.66).", 2},
+        "Deprecated. The option will be removed in a future version. Please use --threshold.", 2},
+    {"threshold", 'f', "THRESHOLD", 0,
+        "Bases with a call probability < THRESHOLD are filtered from results (default 0.66).", 2},
     {"cpg", 0x700, 0, 0,
         "Output records filtered to CpG sites.", 2},
     {"chh", 0x400, 0, 0,
         "Output records filtered to CHH sites.", 2},
     {"chg", 0x500, 0, 0,
         "Output records filtered to CHG sites.", 2},
-    {"aggregate", 0x600, 0, 0,
-        "Output additional aggregated (across strand) counts, requires --cpg or --chg.", 2},
     {"mask", 'k', 0, 0,
         "Respect soft-masking in reference file.", 2},
     {0, 0, 0, 0,
@@ -88,18 +96,15 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state) {
     bool found = false;
     switch (key) {
         case 'a':
-            thresh = atof(arg);
-            if (thresh < 0 || thresh > 1.0) {
-                argp_error (state, "Threshold parameter must be in (0,1), got %s", arg);
-            }
-            arguments->lowthreshold = (int)(thresh * 255);
-            break;
         case 'b':
+            argp_error (state, "Options `-a` and `-b` are deprecated, Please use only `-f`. These option will be removed in a future version.\n");
+            break;
+        case 'f':
             thresh = atof(arg);
             if (thresh < 0 || thresh > 1.0) {
                 argp_error (state, "Threshold parameter must be in (0,1), got %s", arg);
             }
-            arguments->highthreshold = (int)(thresh * 255);
+            arguments->threshold = (int)(thresh * 255);
             break;
         case 'm':
             for (size_t i = 0; i < n_mod_bases; ++i) {
@@ -115,6 +120,9 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state) {
                     "Unrecognised modified base type: %s. ChEBI codes are not supported", arg);
             }
             break;
+        case 0x800:
+            arguments->combine = true;
+            break;
         case 'r':
             arguments->region = arg;
             break;
@@ -206,8 +214,8 @@ static struct argp argp = {options, parse_opt, args_doc, doc};
 arguments_t parse_arguments(int argc, char** argv) {
     arguments_t args;
     args.mod_base = default_mod_base;
-    args.lowthreshold = (int)(0.33 * 255);
-    args.highthreshold = (int)(0.66 * 255);
+    args.combine = false;
+    args.threshold = (int)(0.66 * MAX_QUAL);
     args.bam = NULL;
     args.ref = NULL;
     args.region = NULL;
@@ -243,9 +251,14 @@ arguments_t parse_arguments(int argc, char** argv) {
         fprintf(stderr, "ERROR: If --haplotype is given neither of --tag_name or --tag_value should be provided.\n");
         exit(1);
     }
-    if (args.highthreshold < args.lowthreshold) {
-        fprintf(stderr, "ERROR: --highthreshold must be larger than --lowthreshold\n");
-        exit(1);
+    if (strncmp("5mC", args.mod_base.abbrev, 3) == 0 || strncmp("5hmC", args.mod_base.abbrev, 4)) {
+        fprintf(stderr,
+"WARNING: You have specified either 5mC or 5hmC as a modified base.\n\
+         Oxford Nanopore Basecallers jointly call C, 5mC, and 5hmC. If you\n\
+         wish to combine calls of these bases into a single 'modified'\n\
+         count, please use the `--combine` option. The default behaviour\n\
+         is that calls of alternative modified bases are added to the\n\
+         alternatively-modified count.");
     }
     return args;
 }
